diff libpurple/server.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children b449dc6b8a20
line wrap: on
line diff
--- a/libpurple/server.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/server.h	Mon Mar 19 07:01:17 2007 +0000
@@ -2,9 +2,9 @@
  * @file server.h Server API
  * @ingroup core
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -22,8 +22,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#ifndef _GAIM_SERVER_H_
-#define _GAIM_SERVER_H_
+#ifndef _PURPLE_SERVER_H_
+#define _PURPLE_SERVER_H_
 
 #include "account.h"
 #include "conversation.h"
@@ -38,87 +38,87 @@
  *
  * TODO: Could probably move this into the conversation API.
  *
  * @param typing One of GAIM_TYPING, GAIM_TYPED, or GAIM_NOT_TYPING.
  * @return A quiet-period, specified in seconds, where Gaim will not
  *         send any additional typing notification messages.  Most
  *         protocols should return 0, which means that no additional
  *         GAIM_TYPING messages need to be sent.  If this is 5, for
  *         example, then Gaim will wait five seconds, and if the Gaim
  *         user is still typing then Gaim will send another GAIM_TYPING
  *         message.
  */
-unsigned int serv_send_typing(GaimConnection *gc, const char *name, GaimTypingState state);
+unsigned int serv_send_typing(PurpleConnection *gc, const char *name, PurpleTypingState state);
 
-void serv_move_buddy(GaimBuddy *, GaimGroup *, GaimGroup *);
-int  serv_send_im(GaimConnection *, const char *, const char *, GaimMessageFlags flags);
-void serv_get_info(GaimConnection *, const char *);
-void serv_set_info(GaimConnection *, const char *);
+void serv_move_buddy(PurpleBuddy *, PurpleGroup *, PurpleGroup *);
+int  serv_send_im(PurpleConnection *, const char *, const char *, PurpleMessageFlags flags);
+void serv_get_info(PurpleConnection *, const char *);
+void serv_set_info(PurpleConnection *, const char *);
 
-void serv_add_permit(GaimConnection *, const char *);
-void serv_add_deny(GaimConnection *, const char *);
-void serv_rem_permit(GaimConnection *, const char *);
-void serv_rem_deny(GaimConnection *, const char *);
-void serv_set_permit_deny(GaimConnection *);
-void serv_chat_invite(GaimConnection *, int, const char *, const char *);
-void serv_chat_leave(GaimConnection *, int);
-void serv_chat_whisper(GaimConnection *, int, const char *, const char *);
-int  serv_chat_send(GaimConnection *, int, const char *, GaimMessageFlags flags);
-void serv_alias_buddy(GaimBuddy *);
-void serv_got_alias(GaimConnection *gc, const char *who, const char *alias);
+void serv_add_permit(PurpleConnection *, const char *);
+void serv_add_deny(PurpleConnection *, const char *);
+void serv_rem_permit(PurpleConnection *, const char *);
+void serv_rem_deny(PurpleConnection *, const char *);
+void serv_set_permit_deny(PurpleConnection *);
+void serv_chat_invite(PurpleConnection *, int, const char *, const char *);
+void serv_chat_leave(PurpleConnection *, int);
+void serv_chat_whisper(PurpleConnection *, int, const char *, const char *);
+int  serv_chat_send(PurpleConnection *, int, const char *, PurpleMessageFlags flags);
+void serv_alias_buddy(PurpleBuddy *);
+void serv_got_alias(PurpleConnection *gc, const char *who, const char *alias);
 
 /**
  * Receive a typing message from a remote user.  Either GAIM_TYPING
  * or GAIM_TYPED.  If the user has stopped typing then use
  * serv_got_typing_stopped instead.
  *
  * TODO: Could probably move this into the conversation API.
  *
  * @param timeout If this is a number greater than 0, then
  *        Gaim will wait this number of seconds and then
  *        set this buddy to the GAIM_NOT_TYPING state.  This
  *        is used by protocols that send repeated typing messages
  *        while the user is composing the message.
  */
-void serv_got_typing(GaimConnection *gc, const char *name, int timeout,
-					 GaimTypingState state);
+void serv_got_typing(PurpleConnection *gc, const char *name, int timeout,
+					 PurpleTypingState state);
 
 /**
  * TODO: Could probably move this into the conversation API.
  */
-void serv_got_typing_stopped(GaimConnection *gc, const char *name);
+void serv_got_typing_stopped(PurpleConnection *gc, const char *name);
 
-void serv_got_im(GaimConnection *gc, const char *who, const char *msg,
-				 GaimMessageFlags flags, time_t mtime);
+void serv_got_im(PurpleConnection *gc, const char *who, const char *msg,
+				 PurpleMessageFlags flags, time_t mtime);
 
 /**
  * @param data The hash function should be g_str_hash() and the equal
  *             function should be g_str_equal().
  */
-void serv_join_chat(GaimConnection *, GHashTable *);
+void serv_join_chat(PurpleConnection *, GHashTable *);
 
 /**
  * @param data The hash function should be g_str_hash() and the equal
  *             function should be g_str_equal().
  */
-void serv_reject_chat(GaimConnection *, GHashTable *);
+void serv_reject_chat(PurpleConnection *, GHashTable *);
 
 /**
  * @param data The hash function should be g_str_hash() and the equal
  *             function should be g_str_equal().
  */
-void serv_got_chat_invite(GaimConnection *gc, const char *name,
+void serv_got_chat_invite(PurpleConnection *gc, const char *name,
 						  const char *who, const char *message,
 						  GHashTable *data);
 
-GaimConversation *serv_got_joined_chat(GaimConnection *gc,
+PurpleConversation *serv_got_joined_chat(PurpleConnection *gc,
 									   int id, const char *name);
-void serv_got_chat_left(GaimConnection *g, int id);
-void serv_got_chat_in(GaimConnection *g, int id, const char *who,
-					  GaimMessageFlags flags, const char *message, time_t mtime);
-void serv_send_file(GaimConnection *gc, const char *who, const char *file);
+void serv_got_chat_left(PurpleConnection *g, int id);
+void serv_got_chat_in(PurpleConnection *g, int id, const char *who,
+					  PurpleMessageFlags flags, const char *message, time_t mtime);
+void serv_send_file(PurpleConnection *gc, const char *who, const char *file);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* _GAIM_SERVER_H_ */
+#endif /* _PURPLE_SERVER_H_ */
@@ -2,9 +2,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
@@ -38,87 +38,87 @@
  * TODO: Could probably move this into the conversation API.
  *
- * @param typing One of GAIM_TYPING, GAIM_TYPED, or GAIM_NOT_TYPING.
- * @return A quiet-period, specified in seconds, where Gaim will not
+ * @param typing One of PURPLE_TYPING, PURPLE_TYPED, or PURPLE_NOT_TYPING.
+ * @return A quiet-period, specified in seconds, where Purple will not
  *         send any additional typing notification messages.  Most
  *         protocols should return 0, which means that no additional
@@ -38,87 +38,87 @@
  *         send any additional typing notification messages.  Most
  *         protocols should return 0, which means that no additional
- *         GAIM_TYPING messages need to be sent.  If this is 5, for
- *         example, then Gaim will wait five seconds, and if the Gaim
- *         user is still typing then Gaim will send another GAIM_TYPING
+ *         PURPLE_TYPING messages need to be sent.  If this is 5, for
+ *         example, then Purple will wait five seconds, and if the Purple
+ *         user is still typing then Purple will send another PURPLE_TYPING
  *         message.
  */
@@ -38,87 +38,87 @@
 
 /**
- * Receive a typing message from a remote user.  Either GAIM_TYPING
- * or GAIM_TYPED.  If the user has stopped typing then use
+ * Receive a typing message from a remote user.  Either PURPLE_TYPING
+ * or PURPLE_TYPED.  If the user has stopped typing then use
  * serv_got_typing_stopped instead.
  *
@@ -38,87 +38,87 @@
  *
  * @param timeout If this is a number greater than 0, then
- *        Gaim will wait this number of seconds and then
- *        set this buddy to the GAIM_NOT_TYPING state.  This
+ *        Purple will wait this number of seconds and then
+ *        set this buddy to the PURPLE_NOT_TYPING state.  This
  *        is used by protocols that send repeated typing messages
  *        while the user is composing the message.